@@ -1,12 +1,11 @@
 (********************************************************************)
 (*                                                                  *)
 (*  The Why3 Verification Platform   /   The Why3 Development Team  *)
-(*  Copyright 2010-2024 --  Inria - CNRS - Paris-Saclay University  *)
+(*  Copyright 2010-2025 --  Inria - CNRS - Paris-Saclay University  *)
 (*                                                                  *)
 (*  This software is distributed under the terms of the GNU Lesser  *)
 (*  General Public License version 2.1, with the special exception  *)
 (*  on linking described in file LICENSE.                           *)
-(*                                                                  *)
 (********************************************************************)
 
 open Wstdlib
@@ -231,7 +230,7 @@ let empty_module env n p = {
 }
 
 let close_module, restore_module =
-  let h = Hid.create 17 in
+  let h = Wid.create 17 in
   (fun uc ->
      let th = close_theory uc.muc_theory in (* catches errors *)
      let m = { mod_theory = th;
@@ -240,9 +239,9 @@ let close_module, restore_module =
                mod_known  = uc.muc_known;
                mod_local  = uc.muc_local;
                mod_used   = uc.muc_used; } in
-     Hid.add h th.th_name m;
+     Wid.set h th.th_name m;
      m),
-  (fun th -> Hid.find h th.th_name)
+  (fun th -> Wid.find h th.th_name)
 
 let open_scope uc s = match uc.muc_import with
   | ns :: _ -> { uc with
@@ -1158,6 +1157,7 @@ let save_special_ls cl d d' =
       cl.ls_table <- Mls.add ls ls' cl.ls_table;
   | Dtype _, Dtype _ -> ()
   | Dprop _, Dprop _ -> ()
+  | Ddata _, Ddata _ -> ()
   | _ -> assert false
 
 let clone_type_decl loc inst cl tdl decl kn =
@@ -1370,9 +1370,8 @@ let clone_pdecl loc inst cl uc d = match d.pd_node with
       let ndl, vcl = clone_type_decl loc inst cl tdl d uc.muc_known in
       let uc = List.fold_left add_vc uc vcl in
       let dl = if ndl <> [] then create_type_decl ndl else [] in
-      begin match tdl, dl with
-      | [{itd_its = {its_def = (Range _|Float _)}}], [d'] ->
-          List.iter2 (save_special_ls cl) d.pd_pure d'.pd_pure
+      begin match dl with
+      | [d'] -> List.iter2 (save_special_ls cl) d.pd_pure d'.pd_pure
       | _ -> () end;
       let add uc d = add_pdecl ~warn:false ~vc:false uc d in
       List.fold_left add uc dl
@@ -1487,7 +1486,7 @@ let clone_pdecl loc inst cl uc d = match d.pd_node with
 
 let impl_cl = empty_clones' Sid.empty
 
-let mod_table = Hid.create 17
+let mod_table = Wid.create 17
 
 let theory_add_clone = Theory.add_clone_internal ()
 
@@ -1517,7 +1516,7 @@ let decl_impl uc d =
   | _ -> uc
 
 let need_copy m =
-  Sid.exists (fun id -> Hid.mem mod_table id) m.mod_theory.th_used
+  Sid.exists (fun id -> Wid.mem mod_table id) m.mod_theory.th_used
 
 let pdecl_impl inst uc d =
   let uc = clone_pdecl None inst impl_cl uc d in
@@ -1578,13 +1577,13 @@ and mod_impl' e m =
 
 and mod_impl e m =
   let id = m.mod_theory.th_name in
-  try Hid.find mod_table id with
+  try Wid.find mod_table id with
   | Not_found ->
      if not (need_copy m)
      then m
      else begin
          let m = mod_impl' e m in
-         Hid.add mod_table id m;
+         Wid.set mod_table id m;
          m
        end
 
@@ -1653,8 +1652,8 @@ let mod_impl_register e m mimpl inst =
   let mimpl' = clone_export' mimpl' m inst impl_cl in
   let mimpl' = close_scope mimpl' ~import:false in
   let mimpl' = close_module mimpl' in
-  Hid.add mod_table mimpl.mod_theory.th_name mimpl';
-  Hid.add mod_table m.mod_theory.th_name mimpl'
+  Wid.set mod_table mimpl.mod_theory.th_name mimpl';
+  Wid.set mod_table m.mod_theory.th_name mimpl'
 
 (** {2 WhyML language} *)
 
